@@ -24,11 +24,15 @@
 /
 */
 
+#ifdef _WIN32
 #ifdef DLL_EXPORT
 #define GGRAPH_DECLARE __declspec(dllexport)
 #else
 #define GGRAPH_DECLARE extern
 #endif
+#else
+#define GGRAPH_DECLARE __attribute__ ((visibility("default")))
+#endif
 
 #ifndef _GGRAPH_H
 #define _GGRAPH_H
@@ -118,6 +122,7 @@ extern "C"
 #define GGRAPH_INVALID_PAINT_BITMAP		-23
 #define GGRAPH_INVALID_PAINT_BRUSH		-24
 #define GGRAPH_INVALID_PAINT_FONT		-25
+#define GGRAPH_INVALID_SVG			-26
 
 #define GGRAPH_TRUE	-1
 #define GGRAPH_FALSE	-2
@@ -784,6 +789,15 @@ extern "C"
 						  int start_line,
 						  const void **img_out);
 
+/* SVG images */
+    GGRAPH_DECLARE int gGraphCreateSVG (const unsigned char *svg_document,
+					int svg_bytes, void **svg_handle);
+    GGRAPH_DECLARE int gGraphGetSVGDims (void *svg_handle, double *width,
+					 double *height);
+    GGRAPH_DECLARE int gGraphImageFromSVG (void *handle, double size,
+					   const void **img_out);
+    GGRAPH_DECLARE int gGraphFreeSVG (void *sgv_handle);
+
 #ifdef __cplusplus
 }
 #endif
