@@ -171,7 +171,7 @@ cmp_color_rules2 (const void *p1, const void *p2)
     return color_rule_compare2 (pR1->min, pR2->min, pR2->max);
 }
 
-extern gGraphColorRulePtr
+GGRAPH_PRIVATE gGraphColorRulePtr
 gg_color_rule_create (void)
 {
 /* allocating an empty Color Rule */
@@ -188,7 +188,7 @@ gg_color_rule_create (void)
     return ptr;
 }
 
-extern void
+GGRAPH_PRIVATE void
 gg_color_rule_destroy (gGraphColorRulePtr ptr)
 {
 /* destroying a Color Rule */
@@ -206,7 +206,7 @@ gg_color_rule_destroy (gGraphColorRulePtr ptr)
     free (ptr);
 }
 
-extern gGraphColorMapPtr
+GGRAPH_PRIVATE gGraphColorMapPtr
 gg_color_map_create (void)
 {
 /* allocating an empty Color Map */
@@ -227,7 +227,7 @@ gg_color_map_create (void)
     return ptr;
 }
 
-extern void
+GGRAPH_PRIVATE void
 gg_color_map_destroy (gGraphColorMapPtr ptr)
 {
 /* destroying a Color Map */
@@ -352,7 +352,7 @@ token_to_double (const char *str, double *value)
 	      error = 1;
 	  p++;
       }
-    if (digits > 0 && sign < 2 && comma < 2)
+    if (digits > 0 && sign < 2 && comma < 2 && error == 0)
       {
 	  *value = atof (str);
 	  return 1;
@@ -1175,7 +1175,7 @@ gGraphDestroyColorMap (const void *ptr)
 	gg_color_map_destroy (map);
 }
 
-extern void
+GGRAPH_PRIVATE void
 match_color (gGraphColorMapPtr map, double value, double no_data,
 	     unsigned char *red, unsigned char *green, unsigned char *blue)
 {
@@ -1604,7 +1604,7 @@ gGraphGetStripImageMinMaxValue (const void *in_ptr, double *min_value,
     return GGRAPH_ERROR;
 }
 
-extern gGraphShadedReliefTripleRowPtr
+GGRAPH_PRIVATE gGraphShadedReliefTripleRowPtr
 gg_shaded_relief_triple_row_create (void)
 {
 /* allocating an empty Shaded Relief Triple Row object */
@@ -1634,7 +1634,7 @@ gg_shaded_relief_triple_row_create (void)
     return ptr;
 }
 
-extern void
+GGRAPH_PRIVATE void
 gg_shaded_relief_triple_row_destroy (gGraphShadedReliefTripleRowPtr ptr)
 {
 /* destroying a Shaded Relief Triple Row object */
