@@ -80,9 +80,9 @@ typedef long int count_int;
 #define hsize HSIZE
 
 #ifdef COMPATIBLE
-# define MAXCODE(n_bits)        ((code_int) 1 << (n_bits) - 1)
+#define MAXCODE(n_bits)        ((code_int) 1 << (n_bits) - 1)
 #else /*COMPATIBLE*/
-# define MAXCODE(n_bits)        (((code_int) 1 << (n_bits)) - 1)
+#define MAXCODE(n_bits)        (((code_int) 1 << (n_bits)) - 1)
 #endif /*COMPATIBLE*/
 #define HashTabOf(i)       ctx->htab[i]
 #define CodeTabOf(i)    ctx->codetab[i]
@@ -889,7 +889,6 @@ xgdImageInfosFromGifCtx (xgdIOCtxPtr fd, int *errcode)
     int BitPixel;
     unsigned char buf[16];
     int imw, imh, screen_width, screen_height;
-    int gif87a;
     int bitPixel;
     gGraphImageInfosPtr infos = NULL;
     if (!ReadOK (fd, buf, 6))
@@ -902,14 +901,9 @@ xgdImageInfosFromGifCtx (xgdIOCtxPtr fd, int *errcode)
 	  *errcode = GGRAPH_GIF_CODEC_ERROR;
 	  return NULL;
       }
-    if (memcmp ((char *) buf + 3, "87a", 3) == 0)
-      {
-	  gif87a = 1;
-      }
-    else if (memcmp ((char *) buf + 3, "89a", 3) == 0)
-      {
-	  gif87a = 0;
-      }
+    if (memcmp ((char *) buf + 3, "87a", 3) == 0
+	|| memcmp ((char *) buf + 3, "89a", 3) == 0)
+	;
     else
       {
 	  *errcode = GGRAPH_GIF_CODEC_ERROR;
@@ -951,7 +945,7 @@ xgdImageCreateFromGifCtx (xgdIOCtxPtr fd, int *errcode)
     unsigned char ColorMap[3][MAXCOLORMAPSIZE];
     unsigned char localColorMap[3][MAXCOLORMAPSIZE];
     int imw, imh, screen_width, screen_height;
-    int gif87a, useGlobalColormap;
+    int useGlobalColormap;
     int bitPixel;
     int ZeroDataBlock = FALSE;
     int haveGlobalColormap;
@@ -966,14 +960,9 @@ xgdImageCreateFromGifCtx (xgdIOCtxPtr fd, int *errcode)
 	  *errcode = GGRAPH_GIF_CODEC_ERROR;
 	  return NULL;
       }
-    if (memcmp ((char *) buf + 3, "87a", 3) == 0)
-      {
-	  gif87a = 1;
-      }
-    else if (memcmp ((char *) buf + 3, "89a", 3) == 0)
-      {
-	  gif87a = 0;
-      }
+    if (memcmp ((char *) buf + 3, "87a", 3) == 0
+	|| memcmp ((char *) buf + 3, "89a", 3) == 0)
+	;
     else
       {
 	  *errcode = GGRAPH_GIF_CODEC_ERROR;
@@ -1130,7 +1119,7 @@ xgdImageGifCtx (gGraphImagePtr img, xgdIOCtxPtr out, int is_transparent)
 		      Blue, img);
 }
 
-extern int
+GGRAPH_PRIVATE int
 gg_image_to_gif (const gGraphImagePtr img, void **mem_buf, int *mem_buf_size,
 		 FILE * file, int dest_type, int is_transparent)
 {
@@ -1173,7 +1162,7 @@ gg_image_to_gif (const gGraphImagePtr img, void **mem_buf, int *mem_buf_size,
     return ret;
 }
 
-extern int
+GGRAPH_PRIVATE int
 gg_image_from_gif (int size, const void *data, int source_type,
 		   gGraphImagePtr * image_handle)
 {
@@ -1188,7 +1177,7 @@ gg_image_from_gif (int size, const void *data, int source_type,
     return errcode;
 }
 
-extern int
+GGRAPH_PRIVATE int
 gg_image_infos_from_gif (int size, const void *data, int source_type,
 			 gGraphImageInfosPtr * infos_handle)
 {
