@@ -51,7 +51,7 @@ struct grid_codec_data
     long *row_offsets;
 };
 
-extern int
+GGRAPH_PRIVATE int
 gg_image_strip_prepare_from_hgt (FILE * in, int lon, int lat,
 				 gGraphStripImagePtr * image_handle)
 {
@@ -135,7 +135,7 @@ gg_image_strip_prepare_from_hgt (FILE * in, int lon, int lat,
     return ret;
 }
 
-extern void
+GGRAPH_PRIVATE void
 gg_grid_codec_destroy (void *p)
 {
 /* destroyng the GRID codec data */
@@ -191,7 +191,7 @@ read_from_hgt (FILE * in, gGraphStripImagePtr img, void *scanline)
     return GGRAPH_OK;
 }
 
-extern int
+GGRAPH_PRIVATE int
 gg_image_strip_read_from_hgt (gGraphStripImagePtr img, int *progress)
 {
 /* decoding an HGT-GRID [by strip] */
@@ -295,7 +295,6 @@ gGraphImageInfosFromHgtFile (const char *path, int lat, int lon,
     FILE *in = NULL;
     gGraphImageInfosPtr infos = NULL;
     long file_length;
-    int type;
     int width;
     int height;
     double pixel_size;
@@ -314,14 +313,12 @@ gGraphImageInfosFromHgtFile (const char *path, int lat, int lon,
     file_length = ftell (in);
     if (file_length == (1201 * 1201 * sizeof (short)))
       {
-	  type = GRID_HGT_3;
 	  width = 1201;
 	  height = 1201;
 	  pixel_size = 1.0 / 1200.0;
       }
     else if (file_length == (3601 * 3601 * sizeof (short)))
       {
-	  type = GRID_HGT_1;
 	  width = 3601;
 	  height = 3601;
 	  pixel_size = 1.0 / 3600.0;
@@ -608,7 +605,7 @@ cvtToInt (const char *str, int *value)
 	      error = 1;
 	  p++;
       }
-    if (digits > 0 && sign < 2)
+    if (digits > 0 && sign < 2 && error == 0)
       {
 	  *value = atoi (str);
 	  return 1;
@@ -642,7 +639,7 @@ cvtToDouble (const char *str, double *value)
 	      error = 1;
 	  p++;
       }
-    if (digits > 0 && sign < 2 && comma < 2)
+    if (digits > 0 && sign < 2 && comma < 2 && error == 0)
       {
 	  *value = atof (str);
 	  return 1;
@@ -1539,7 +1536,7 @@ gGraphImageInfosFromAscFile (const char *path, const void **infos_handle)
     return GGRAPH_OK;
 }
 
-extern int
+GGRAPH_PRIVATE int
 gg_image_strip_prepare_from_bin_hdr (FILE * in, const char *hdr_path,
 				     gGraphStripImagePtr * image_handle)
 {
@@ -1637,7 +1634,7 @@ gg_image_strip_prepare_from_bin_hdr (FILE * in, const char *hdr_path,
     return ret;
 }
 
-extern int
+GGRAPH_PRIVATE int
 gg_image_strip_prepare_from_flt_hdr (FILE * in, const char *hdr_path,
 				     gGraphStripImagePtr * image_handle)
 {
@@ -1735,7 +1732,7 @@ gg_image_strip_prepare_from_flt_hdr (FILE * in, const char *hdr_path,
     return ret;
 }
 
-extern int
+GGRAPH_PRIVATE int
 gg_image_strip_prepare_from_dem_hdr (FILE * in, const char *hdr_path,
 				     gGraphStripImagePtr * image_handle)
 {
@@ -1849,7 +1846,7 @@ parse_asc_offsets (FILE * in, int height, long **row_offsets)
     return 1;
 }
 
-extern int
+GGRAPH_PRIVATE int
 gg_image_strip_prepare_from_ascii_grid (FILE * in,
 					gGraphStripImagePtr * image_handle)
 {
@@ -2039,7 +2036,7 @@ read_from_bin_grid (FILE * in, gGraphStripImagePtr img, int sample,
     return GGRAPH_OK;
 }
 
-extern int
+GGRAPH_PRIVATE int
 gg_image_strip_read_from_bin_grid (gGraphStripImagePtr img, int *progress)
 {
 /* decoding a BIN-GRID or a FLT-GRID [by strip] */
@@ -2064,7 +2061,7 @@ gg_image_strip_read_from_bin_grid (gGraphStripImagePtr img, int *progress)
     return GGRAPH_ERROR;
 }
 
-extern int
+GGRAPH_PRIVATE int
 gg_image_strip_read_from_dem_grid (gGraphStripImagePtr img, int *progress)
 {
 /* decoding a DEM-GRID [by strip] */
@@ -2150,7 +2147,7 @@ read_from_ascii_grid (FILE * in, gGraphStripImagePtr img, long *row_offsets)
     return GGRAPH_OK;
 }
 
-extern int
+GGRAPH_PRIVATE int
 gg_image_strip_read_from_ascii_grid (gGraphStripImagePtr img, int *progress)
 {
 /* decoding an ASCII-GRID [by strip] */
@@ -2170,7 +2167,7 @@ gg_image_strip_read_from_ascii_grid (gGraphStripImagePtr img, int *progress)
     return GGRAPH_ERROR;
 }
 
-extern int
+GGRAPH_PRIVATE int
 gg_image_prepare_to_ascii_grid_by_strip (const gGraphStripImagePtr img,
 					 FILE * out)
 {
@@ -2192,7 +2189,7 @@ gg_image_prepare_to_ascii_grid_by_strip (const gGraphStripImagePtr img,
     return GGRAPH_OK;
 }
 
-extern int
+GGRAPH_PRIVATE int
 gg_image_write_to_ascii_grid_by_strip (const gGraphStripImagePtr img,
 				       int *progress)
 {
@@ -2320,7 +2317,7 @@ gg_image_write_to_ascii_grid_by_strip (const gGraphStripImagePtr img,
     return GGRAPH_OK;
 }
 
-extern int
+GGRAPH_PRIVATE int
 gg_image_prepare_to_bin_hdr_by_strip (const gGraphStripImagePtr img)
 {
 /* preparing to export a BIN+HDR GRID [by strips] */
@@ -2361,7 +2358,7 @@ gg_image_prepare_to_bin_hdr_by_strip (const gGraphStripImagePtr img)
     return GGRAPH_OK;
 }
 
-extern int
+GGRAPH_PRIVATE int
 gg_image_prepare_to_flt_hdr_by_strip (const gGraphStripImagePtr img)
 {
 /* preparing to export a FLT+HDR GRID [by strips] */
@@ -2402,7 +2399,7 @@ gg_image_prepare_to_flt_hdr_by_strip (const gGraphStripImagePtr img)
     return GGRAPH_OK;
 }
 
-extern int
+GGRAPH_PRIVATE int
 gg_image_write_to_bin_hdr_by_strip (const gGraphStripImagePtr img,
 				    int *progress)
 {
@@ -2470,7 +2467,7 @@ gg_image_write_to_bin_hdr_by_strip (const gGraphStripImagePtr img,
     return GGRAPH_OK;
 }
 
-extern int
+GGRAPH_PRIVATE int
 gg_image_write_to_flt_hdr_by_strip (const gGraphStripImagePtr img,
 				    int *progress)
 {
