@@ -55,7 +55,7 @@ gGraphSmartPrintf (double value, char *buf)
 	buf[i] = '\0';
 }
 
-extern int
+GGRAPH_PRIVATE int
 gg_endian_arch ()
 {
 /* checking if target CPU is a little-endian one */
@@ -70,7 +70,7 @@ gg_endian_arch ()
     return 1;
 }
 
-extern short
+GGRAPH_PRIVATE short
 gg_import_int16 (const unsigned char *p, int little_endian,
 		 int little_endian_arch)
 {
@@ -115,7 +115,7 @@ gg_import_int16 (const unsigned char *p, int little_endian,
     return convert.short_value;
 }
 
-extern unsigned short
+GGRAPH_PRIVATE unsigned short
 gg_import_uint16 (const unsigned char *p, int little_endian,
 		  int little_endian_arch)
 {
@@ -160,7 +160,7 @@ gg_import_uint16 (const unsigned char *p, int little_endian,
     return convert.short_value;
 }
 
-extern int
+GGRAPH_PRIVATE int
 gg_import_int32 (const unsigned char *p, int little_endian,
 		 int little_endian_arch)
 {
@@ -213,7 +213,7 @@ gg_import_int32 (const unsigned char *p, int little_endian,
     return convert.int_value;
 }
 
-extern unsigned int
+GGRAPH_PRIVATE unsigned int
 gg_import_uint32 (const unsigned char *p, int little_endian,
 		  int little_endian_arch)
 {
@@ -266,7 +266,7 @@ gg_import_uint32 (const unsigned char *p, int little_endian,
     return convert.int_value;
 }
 
-extern float
+GGRAPH_PRIVATE float
 gg_import_float (const unsigned char *p, int little_endian,
 		 int little_endian_arch)
 {
@@ -319,7 +319,7 @@ gg_import_float (const unsigned char *p, int little_endian,
     return convert.flt_value;
 }
 
-extern double
+GGRAPH_PRIVATE double
 gg_import_double (const unsigned char *p, int little_endian,
 		  int little_endian_arch)
 {
@@ -388,7 +388,7 @@ gg_import_double (const unsigned char *p, int little_endian,
     return convert.double_value;
 }
 
-extern void
+GGRAPH_PRIVATE void
 gg_export_int16 (short value, unsigned char *p, int little_endian,
 		 int little_endian_arch)
 {
@@ -433,7 +433,7 @@ gg_export_int16 (short value, unsigned char *p, int little_endian,
       }
 }
 
-extern void
+GGRAPH_PRIVATE void
 gg_export_uint16 (unsigned short value, unsigned char *p, int little_endian,
 		  int little_endian_arch)
 {
@@ -478,7 +478,7 @@ gg_export_uint16 (unsigned short value, unsigned char *p, int little_endian,
       }
 }
 
-extern void
+GGRAPH_PRIVATE void
 gg_export_int32 (int value, unsigned char *p, int little_endian,
 		 int little_endian_arch)
 {
@@ -531,7 +531,7 @@ gg_export_int32 (int value, unsigned char *p, int little_endian,
       }
 }
 
-extern void
+GGRAPH_PRIVATE void
 gg_export_uint32 (unsigned int value, unsigned char *p, int little_endian,
 		  int little_endian_arch)
 {
@@ -584,7 +584,7 @@ gg_export_uint32 (unsigned int value, unsigned char *p, int little_endian,
       }
 }
 
-extern void
+GGRAPH_PRIVATE void
 gg_export_float (float value, unsigned char *p, int little_endian,
 		 int little_endian_arch)
 {
@@ -637,7 +637,7 @@ gg_export_float (float value, unsigned char *p, int little_endian,
       }
 }
 
-extern void
+GGRAPH_PRIVATE void
 gg_export_double (double value, unsigned char *p, int little_endian,
 		  int little_endian_arch)
 {
@@ -1025,7 +1025,7 @@ trimMemory (dynamicPtr * dp)
     return xgdReallocMemory (dp, dp->logicalSize);
 }
 
-extern int
+GGRAPH_PRIVATE int
 overflow2 (int a, int b)
 {
     if (a < 0 || b < 0)
@@ -1045,7 +1045,7 @@ overflow2 (int a, int b)
     return 0;
 }
 
-extern void *
+GGRAPH_PRIVATE void *
 xgdDPExtractData (struct xgdIOCtx *ctx, int *size)
 {
     dynamicPtr *dp;
@@ -1072,13 +1072,13 @@ xgdDPExtractData (struct xgdIOCtx *ctx, int *size)
     return data;
 }
 
-extern xgdIOCtx *
+GGRAPH_PRIVATE xgdIOCtx *
 xgdNewDynamicCtx (int initialSize, const void *data, int mem_or_file)
 {
     return xgdNewDynamicCtxEx (initialSize, data, XGD_CTX_FREE, mem_or_file);
 }
 
-extern xgdIOCtx *
+GGRAPH_PRIVATE xgdIOCtx *
 xgdNewDynamicCtxEx (int initialSize, const void *data, int freeOKFlag,
 		    int mem_or_file)
 {
@@ -1126,13 +1126,13 @@ xgdNewDynamicCtxEx (int initialSize, const void *data, int freeOKFlag,
     return (xgdIOCtx *) ctx;
 }
 
-extern int
+GGRAPH_PRIVATE int
 xgdPutBuf (const void *buf, int size, xgdIOCtx * ctx)
 {
     return (ctx->putBuf) (ctx, buf, size);
 }
 
-extern int
+GGRAPH_PRIVATE int
 xgdGetBuf (void *buf, int size, xgdIOCtx * ctx)
 {
     return (ctx->getBuf) (ctx, buf, size);
