@@ -400,7 +400,7 @@ xgdImageJpegCtx (gGraphImagePtr img, xgdIOCtx * outfile, int quality)
     return GGRAPH_OK;
 }
 
-extern void
+GGRAPH_PRIVATE void
 gg_jpeg_codec_destroy (void *p)
 {
 /* destroyng the JPEG codec data */
@@ -445,7 +445,6 @@ xgdStripImageJpegCtx (gGraphStripImagePtr img, xgdIOCtx * outfile, int quality)
     struct jpeg_compress_struct cinfo;
     struct jpeg_error_mgr jerr;
     volatile JSAMPROW row = 0;
-    JSAMPROW rowptr[1];
     jmpbuf_wrapper jmpbufw;
     char comment[255];
     struct jpeg_codec_data *jpeg_codec;
@@ -486,7 +485,6 @@ xgdStripImageJpegCtx (gGraphStripImagePtr img, xgdIOCtx * outfile, int quality)
 	  jpeg_destroy_compress (&cinfo);
 	  return GGRAPH_INSUFFICIENT_MEMORY;
       }
-    rowptr[0] = row;
     jpeg_start_compress (&cinfo, TRUE);
     sprintf (comment, "CREATOR: jpeg-wrapper (using IJG JPEG v%d),",
 	     JPEG_LIB_VERSION);
@@ -952,7 +950,6 @@ xgdStripImageCreateFromJpegCtx (xgdIOCtx * infile, int *errcode, FILE * file)
     volatile gGraphStripImagePtr img = 0;
     int retval;
     int channels = 3;
-    int inverted = 0;
     struct jpeg_codec_data *jpeg_codec;
     memset (&cinfo, 0, sizeof (cinfo));
     memset (&jerr, 0, sizeof (jerr));
@@ -1054,7 +1051,6 @@ xgdStripImageCreateFromJpegCtx (xgdIOCtx * infile, int *errcode, FILE * file)
 		    (marker->data_length >= 12)
 		    && (!strncmp ((const char *) marker->data, "Adobe", 5)))
 		  {
-		      inverted = 1;
 		      break;
 		  }
 		marker = marker->next;
@@ -1208,7 +1204,7 @@ xgdStripImageReadFromJpegCtx (gGraphStripImagePtr img)
     return GGRAPH_OK;
 }
 
-extern int
+GGRAPH_PRIVATE int
 gg_image_to_jpeg (const gGraphImagePtr img, void **mem_buf, int *mem_buf_size,
 		  FILE * file, int dest_type, int quality)
 {
@@ -1251,7 +1247,7 @@ gg_image_to_jpeg (const gGraphImagePtr img, void **mem_buf, int *mem_buf_size,
     return ret;
 }
 
-extern int
+GGRAPH_PRIVATE int
 gg_image_prepare_to_jpeg_by_strip (const gGraphStripImagePtr img, FILE * file,
 				   int quality)
 {
@@ -1266,7 +1262,7 @@ gg_image_prepare_to_jpeg_by_strip (const gGraphStripImagePtr img, FILE * file,
     return xgdStripImageJpegCtx (img, out, quality);
 }
 
-extern int
+GGRAPH_PRIVATE int
 gg_image_write_to_jpeg_by_strip (const gGraphStripImagePtr img, int *progress)
 {
 /* scanline(s) JPEG compression [by strip] */
@@ -1278,7 +1274,7 @@ gg_image_write_to_jpeg_by_strip (const gGraphStripImagePtr img, int *progress)
     return ret;
 }
 
-extern int
+GGRAPH_PRIVATE int
 gg_image_from_jpeg (int size, const void *data, int source_type,
 		    gGraphImagePtr * image_handle, int scale)
 {
@@ -1293,7 +1289,7 @@ gg_image_from_jpeg (int size, const void *data, int source_type,
     return errcode;
 }
 
-extern int
+GGRAPH_PRIVATE int
 gg_image_infos_from_jpeg (int size, const void *data, int source_type,
 			  gGraphImageInfosPtr * infos_handle)
 {
@@ -1308,7 +1304,7 @@ gg_image_infos_from_jpeg (int size, const void *data, int source_type,
     return errcode;
 }
 
-extern int
+GGRAPH_PRIVATE int
 gg_image_strip_prepare_from_jpeg (FILE * file,
 				  gGraphStripImagePtr * image_handle)
 {
@@ -1322,7 +1318,7 @@ gg_image_strip_prepare_from_jpeg (FILE * file,
     return errcode;
 }
 
-extern int
+GGRAPH_PRIVATE int
 gg_image_strip_read_from_jpeg (gGraphStripImagePtr img, int *progress)
 {
 /* uncompressing a JPEG [by strips] */
