@@ -796,7 +796,7 @@ xgdImageCreateFromPngCtx (xgdIOCtx * infile, int *errcode, int scale)
     return img;
 }
 
-extern void
+GGRAPH_PRIVATE void
 gg_png_codec_destroy (void *p)
 {
 /* destroyng the PNG codec data */
@@ -2318,7 +2318,7 @@ image_prepare_to_png_rgba_by_strip (const gGraphStripImagePtr img, FILE * file,
 					quantization_factor);
 }
 
-extern int
+GGRAPH_PRIVATE int
 gg_image_to_png (const gGraphImagePtr img, void **mem_buf, int *mem_buf_size,
 		 FILE * file, int dest_type, int compression_level,
 		 int quantization_factor, int interlaced, int is_transparent)
@@ -2341,7 +2341,7 @@ gg_image_to_png (const gGraphImagePtr img, void **mem_buf, int *mem_buf_size,
 			     interlaced);
 }
 
-extern int
+GGRAPH_PRIVATE int
 gg_image_prepare_to_png_by_strip (const gGraphStripImagePtr img,
 				  FILE * file, int compression_level,
 				  int quantization_factor)
@@ -2362,7 +2362,7 @@ gg_image_prepare_to_png_by_strip (const gGraphStripImagePtr img,
 					      quantization_factor);
 }
 
-extern int
+GGRAPH_PRIVATE int
 gg_image_write_to_png_by_strip (const gGraphStripImagePtr img, int *progress)
 {
 /* scanline(s) PNG compression [by strip] */
@@ -2374,7 +2374,7 @@ gg_image_write_to_png_by_strip (const gGraphStripImagePtr img, int *progress)
     return ret;
 }
 
-extern int
+GGRAPH_PRIVATE int
 gg_image_from_png (int size, const void *data, int source_type,
 		   gGraphImagePtr * image_handle, int scale)
 {
@@ -2389,7 +2389,7 @@ gg_image_from_png (int size, const void *data, int source_type,
     return errcode;
 }
 
-extern int
+GGRAPH_PRIVATE int
 gg_image_infos_from_png (int size, const void *data, int source_type,
 			 gGraphImageInfosPtr * infos_handle)
 {
@@ -2404,7 +2404,7 @@ gg_image_infos_from_png (int size, const void *data, int source_type,
     return errcode;
 }
 
-extern int
+GGRAPH_PRIVATE int
 gg_image_strip_prepare_from_png (FILE * file,
 				 gGraphStripImagePtr * image_handle)
 {
@@ -2418,7 +2418,7 @@ gg_image_strip_prepare_from_png (FILE * file,
     return errcode;
 }
 
-extern int
+GGRAPH_PRIVATE int
 gg_image_strip_read_from_png (gGraphStripImagePtr img, int *progress)
 {
 /* uncompressing a PNG [by strips] */
