@@ -1039,7 +1039,7 @@ quantize_object_free (QuantizeObj * quantobj)
     free (quantobj);
 }
 
-extern int
+GGRAPH_PRIVATE int
 gg_image_resample_as_palette (const gGraphImagePtr img, int num_colors)
 {
 /* applies quantization to the current image, so to get 256/16/4 colors */
